pub struct BenchmarkComparisonV1 {
pub name: String,
pub profile: CodecProfileV1,
pub metrics: CompressionEvalV1,
}Fields
name: Stringprofile: CodecProfileV1metrics: CompressionEvalV1Trait Implementations
Sourceimpl Clone for BenchmarkComparisonV1
impl Clone for BenchmarkComparisonV1
Sourcefn clone(&self) -> BenchmarkComparisonV1
fn clone(&self) -> BenchmarkComparisonV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchmarkComparisonV1
impl Debug for BenchmarkComparisonV1
Sourceimpl<'de> Deserialize<'de> for BenchmarkComparisonV1
impl<'de> Deserialize<'de> for BenchmarkComparisonV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchmarkComparisonV1
impl JsonSchema for BenchmarkComparisonV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchmarkComparisonV1
impl PartialEq for BenchmarkComparisonV1
Sourcefn eq(&self, other: &BenchmarkComparisonV1) -> bool
fn eq(&self, other: &BenchmarkComparisonV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BenchmarkComparisonV1
impl Serialize for BenchmarkComparisonV1
impl StructuralPartialEq for BenchmarkComparisonV1