pub struct BenchmarkCorpus {
pub dim: usize,
pub db_size: usize,
pub queries: usize,
pub seed: u64,
pub generator: String,
}Fields
dim: usizedb_size: usizequeries: usizeseed: u64generator: StringTrait Implementations
Sourceimpl Clone for BenchmarkCorpus
impl Clone for BenchmarkCorpus
Sourcefn clone(&self) -> BenchmarkCorpus
fn clone(&self) -> BenchmarkCorpus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchmarkCorpus
impl Debug for BenchmarkCorpus
Sourceimpl<'de> Deserialize<'de> for BenchmarkCorpus
impl<'de> Deserialize<'de> for BenchmarkCorpus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BenchmarkCorpus
Sourceimpl JsonSchema for BenchmarkCorpus
impl JsonSchema for BenchmarkCorpus
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchmarkCorpus
impl PartialEq for BenchmarkCorpus
Sourcefn eq(&self, other: &BenchmarkCorpus) -> bool
fn eq(&self, other: &BenchmarkCorpus) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BenchmarkCorpus
impl Serialize for BenchmarkCorpus
impl StructuralPartialEq for BenchmarkCorpus