pub struct BenchmarkReceiptV1 {
pub schema: String,
pub profile: CodecProfileV1,
pub corpus: BenchmarkCorpus,
pub metrics: CompressionEvalV1,
pub comparisons: Vec<BenchmarkComparisonV1>,
pub commands: Vec<String>,
pub warnings: Vec<String>,
}Expand description
Machine-readable benchmark receipt.
Fields
schema: Stringprofile: CodecProfileV1corpus: BenchmarkCorpusmetrics: CompressionEvalV1comparisons: Vec<BenchmarkComparisonV1>commands: Vec<String>warnings: Vec<String>Trait Implementations
Sourceimpl Clone for BenchmarkReceiptV1
impl Clone for BenchmarkReceiptV1
Sourcefn clone(&self) -> BenchmarkReceiptV1
fn clone(&self) -> BenchmarkReceiptV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchmarkReceiptV1
impl Debug for BenchmarkReceiptV1
Sourceimpl<'de> Deserialize<'de> for BenchmarkReceiptV1
impl<'de> Deserialize<'de> for BenchmarkReceiptV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchmarkReceiptV1
impl JsonSchema for BenchmarkReceiptV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchmarkReceiptV1
impl PartialEq for BenchmarkReceiptV1
Sourcefn eq(&self, other: &BenchmarkReceiptV1) -> bool
fn eq(&self, other: &BenchmarkReceiptV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BenchmarkReceiptV1
impl Serialize for BenchmarkReceiptV1
impl StructuralPartialEq for BenchmarkReceiptV1