pub struct CompressionEvalV1 {
pub schema: String,
pub recall_at_k: f32,
pub mean_absolute_error: f32,
pub queries: usize,
pub db_size: usize,
pub top_k: usize,
}Expand description
Summary of an exact-vs-compressed evaluation run.
Fields
schema: Stringrecall_at_k: f32mean_absolute_error: f32queries: usizedb_size: usizetop_k: usizeTrait Implementations
Sourceimpl Clone for CompressionEvalV1
impl Clone for CompressionEvalV1
Sourcefn clone(&self) -> CompressionEvalV1
fn clone(&self) -> CompressionEvalV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompressionEvalV1
impl Debug for CompressionEvalV1
Sourceimpl<'de> Deserialize<'de> for CompressionEvalV1
impl<'de> Deserialize<'de> for CompressionEvalV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CompressionEvalV1
impl JsonSchema for CompressionEvalV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompressionEvalV1
impl PartialEq for CompressionEvalV1
Sourcefn eq(&self, other: &CompressionEvalV1) -> bool
fn eq(&self, other: &CompressionEvalV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CompressionEvalV1
impl Serialize for CompressionEvalV1
impl StructuralPartialEq for CompressionEvalV1