pub struct PackedCompressionStatsV1 {
pub raw_fp32_bytes: usize,
pub fp16_baseline_bytes: usize,
pub legacy_logical_bytes: usize,
pub packed_sidecar_bytes: usize,
}Fields
raw_fp32_bytes: usizefp16_baseline_bytes: usizelegacy_logical_bytes: usizepacked_sidecar_bytes: usizeTrait Implementations
Sourceimpl Clone for PackedCompressionStatsV1
impl Clone for PackedCompressionStatsV1
Sourcefn clone(&self) -> PackedCompressionStatsV1
fn clone(&self) -> PackedCompressionStatsV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PackedCompressionStatsV1
impl Debug for PackedCompressionStatsV1
Sourceimpl<'de> Deserialize<'de> for PackedCompressionStatsV1
impl<'de> Deserialize<'de> for PackedCompressionStatsV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PackedCompressionStatsV1
Sourceimpl JsonSchema for PackedCompressionStatsV1
impl JsonSchema for PackedCompressionStatsV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PackedCompressionStatsV1
impl PartialEq for PackedCompressionStatsV1
Sourcefn eq(&self, other: &PackedCompressionStatsV1) -> bool
fn eq(&self, other: &PackedCompressionStatsV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PackedCompressionStatsV1
impl Serialize for PackedCompressionStatsV1
impl StructuralPartialEq for PackedCompressionStatsV1